/****************************************************************************
** Meta object code from reading C++ file 'capresource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kweathercore-26.04.0/src/capresource.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'capresource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KWeatherCore11CAPResourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KWeatherCore::CAPResource::qt_create_metaobjectdata<qt_meta_tag_ZN12KWeatherCore11CAPResourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWeatherCore::CAPResource",
        "description",
        "mimeTypeName",
        "mimeType",
        "QMimeType",
        "size",
        "qsizetype",
        "hasSize",
        "uri",
        "QUrl",
        "digest"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'description'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'mimeTypeName'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'mimeType'
        QtMocHelpers::PropertyData<QMimeType>(3, 0x80000000 | 4, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'size'
        QtMocHelpers::PropertyData<qsizetype>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'hasSize'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
        // property 'uri'
        QtMocHelpers::PropertyData<QUrl>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'digest'
        QtMocHelpers::PropertyData<QByteArray>(10, QMetaType::QByteArray, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CAPResource, qt_meta_tag_ZN12KWeatherCore11CAPResourceE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWeatherCore::CAPResource::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KWeatherCore11CAPResourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KWeatherCore11CAPResourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KWeatherCore11CAPResourceE_t>.metaTypes,
    nullptr
} };

void KWeatherCore::CAPResource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<CAPResource *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->mimeTypeName(); break;
        case 2: *reinterpret_cast<QMimeType*>(_v) = _t->mimeType(); break;
        case 3: *reinterpret_cast<qsizetype*>(_v) = _t->size(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hasSize(); break;
        case 5: *reinterpret_cast<QUrl*>(_v) = _t->uri(); break;
        case 6: *reinterpret_cast<QByteArray*>(_v) = _t->digest(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
